@@ -117,15 +117,40 @@ class EloquaBulkClient(object):
     """
     entity: accounts, activities, campaignResponses, contacts
     """
-    def create_export(self, name, entity, fields=None, filter=None):
+    def create_export(
+        self,
+        name,
+        entity,
+        fields=None,
+        filter=None,
+        customObjectId=None,
+        activityType=None
+    ):
+        # if fields aren't provided, then fetch all fields of the entity
+        if fields is None:
+            if entity == 'contacts':
+                fields = self._get_fields_dict(entity=entity)
+            elif entity == 'customObjects':
+                fields = self._get_fields_dict(
+                    entity=entity,
+                    parentId=customObjectId)
+            elif entity == 'activities':
+                fields = self._get_fields_dict(
+                    entity=entity,
+                    activityType=activityType)
+
         data = {
             'name': name,
             'fields': fields,
             'filter': filter
         }
 
-        url = '{base_url}/{entity}/exports'.format(
-            base_url=self.bulk_url, entity=entity)
+        if entity in ('contacts', 'activities'):
+            url = '{base_url}/{entity}/exports'.format(
+                base_url=self.bulk_url, entity=entity)
+        elif entity == 'customObjects':
+            url = '{base_url}/{entity}/{parentId}/exports'.format(
+                base_url=self.bulk_url, entity=entity, parentId=customObjectId)
 
         resp = self.post(url, data)
 
@@ -187,14 +212,53 @@ class EloquaBulkClient(object):
 
         return resp
 
-    def get_fields(self, entity):
-        url = '{base_url}/{entity}/fields'.format(
-            base_url=self.bulk_url,
-            entity=entity)
+    def get_fields(self, entity, parentId=None, activityType=None):
+        if entity in ('contacts', 'activities'):
+            url = '{base_url}/{entity}/fields'.format(
+                base_url=self.bulk_url,
+                entity=entity)
 
-        resp = self.get(url)
+            resp = self.get(url)
+            fields = resp['items']
 
-        return resp
+            if entity == 'contacts':
+                return fields
+
+            if activityType is not None:
+                filtered = []
+                for field in fields:
+                    if activityType in field['activityTypes']:
+                        filtered.append(field)
+
+                return filtered
+
+            return fields
+
+        elif entity == 'customObjects':
+            if parentId is not None:
+                url = '{base_url}/{entity}/{parentId}/fields'.format(
+                    base_url=self.bulk_url,
+                    entity=entity,
+                    parentId=parentId)
+
+                resp = self.get(url)
+                fields = resp['items']
+
+                return fields
+
+            else:
+                raise TypeError(
+                    'You must provide parentId (custom object id)'
+                )
+
+    def _get_fields_dict(self, entity, parentId=None, activityType=None):
+        fields_dict = {}
+        fields = self.get_fields(entity, parentId, activityType)
+
+        for field in fields:
+            fields_dict[field['internalName']] = field['statement']
+
+        return fields_dict
 
     def make_request(self, **kwargs):
         if self.debug:
